@@ -1,12 +1,12 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
 
 #include "filtermailapptest.h"
-#include <MailImporter/FilterMailApp>
 #include "filterimportertest.h"
+#include <MailImporter/FilterMailApp>
 #include <QTest>
 
 FilterMailAppTest::FilterMailAppTest(QObject *parent)
@@ -26,7 +26,7 @@ void FilterMailAppTest::canNotImportDataEmptyPath()
 {
     MailImporter::FilterMailApp filter;
     MailImporter::FilterInfo info;
-    auto *importerTest = new FilterImporterTest(&info);
+    auto importerTest = new FilterImporterTest(&info);
     filter.setFilterImporter(importerTest);
     filter.setFilterInfo(&info);
     filter.importMails(QString());
@@ -38,7 +38,7 @@ void FilterMailAppTest::canNotImportDataUnknowPath()
 {
     MailImporter::FilterMailApp filter;
     MailImporter::FilterInfo info;
-    auto *importerTest = new FilterImporterTest(&info);
+    auto importerTest = new FilterImporterTest(&info);
     filter.setFilterImporter(importerTest);
     filter.setFilterInfo(&info);
     filter.importMails(QStringLiteral("/foo/kde/bla/toto/"));
