@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
 
-#ifndef FILTERICEDOVETEST_H
-#define FILTERICEDOVETEST_H
+#pragma once
 
 #include <QObject>
 
@@ -22,5 +21,3 @@ private Q_SLOTS:
     void canNotImportDataUnknowPath();
     void canNotImportDataWhenHomeDirSelected();
 };
-
-#endif // FILTERICEDOVETEST_H
